# :package:  S3 radar

Simple cli tool for measurement s3 network bandwidth

---

## :arrow_down: Installation

### :snake: PIP

```bash
pip install s3_radar
```

### :honey_pot: Poetry

```bash
poetry add s3_radar
```

## :cake: How to use it
